.app__body .modal .GenericModal.channel-bookmarks-create-modal .modal-body .form-control{height:40px;border:unset}.channel-bookmarks-create-modal .linkInput{margin-bottom:3rem;color:rgba(var(--center-channel-color-rgb), 0.72)}.channel-bookmarks-create-modal .Input___customMessage{line-height:14px}.channel-bookmarks-create-modal .LoadingSpinner{padding:10px 12px;font-size:16px}
#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body{display:flex;flex-direction:column;gap:20px;overflow-y:visible;transition:height 200ms ease}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body.multi-team{min-height:340px}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body.single-team{height:230px}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body.loading{height:152px}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body.error{height:unset}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body .new-channel-modal__url{margin-top:-20px}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body .loadingIndicator{display:block;width:32px;height:32px;margin:36px auto 48px;font-size:32px}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body .conversion-error{color:var(--error-text)}#convert-gm-to-channel-modal .DropDown__menu{z-index:999;max-height:120px}#convert-gm-to-channel-modal .DropDown__menu-list{z-index:999;max-height:120px}#convert-gm-to-channel-modal .modal-body{overflow:visible}#convert-gm-to-channel-modal .GenericModal__button.delete.disabled{color:var(--button-color) !important;opacity:.65}
.field-selector-menu-button{width:100%;height:40px;justify-content:start;border:none;font-weight:normal}.field-selector-menu-button:hover{background:rgba(var(--center-channel-color-rgb), 0.04)}.field-selector-menu-button:focus,.field-selector-menu-button[aria-expanded=true]{background:rgba(var(--button-bg-rgb), 0.08)}.field-selector-menu-button.disabled{cursor:not-allowed;opacity:.6}.field-selector-menu-button>span>span:first-child:not([style*="flex-wrap: wrap"]){overflow:hidden;padding-inline-start:10px;text-overflow:ellipsis;white-space:nowrap}.value-selector-menu-button__multi-values-container{display:flex;overflow:hidden;flex-grow:1;flex-wrap:wrap;gap:2px}.value-selector-menu-button__inner-wrapper{display:flex;width:100%;align-items:center;justify-content:space-between}.values-editor{width:100%}.values-editor .select__multi-value{display:flex;height:24px;align-items:center;border-radius:4px;margin:2px;background-color:rgba(var(--center-channel-color-rgb), 0.08)}.values-editor .select__multi-value__label{padding:0 4px 0 8px;font-size:12px}.values-editor .select__multi-value__remove{padding:0 4px;cursor:pointer}.values-editor .select__multi-value__remove:hover{background-color:rgba(var(--center-channel-color-rgb), 0.16)}.values-editor__simple-input{width:100%;height:40px;border:none;background:rgba(0,0,0,0);font-size:14px;padding-inline-start:22px}.values-editor__simple-input:focus{background:rgba(var(--center-channel-color-rgb), 0.06);outline:none}.values-editor__simple-input:disabled{cursor:not-allowed;opacity:.6}.values-editor .MenuItem__trailing-elements{display:flex;align-items:center;gap:4px}
.editor__test-btn{display:flex;align-items:center;justify-content:center;padding:10px 16px;border:1px solid var(--button-bg);border-radius:4px;background:rgba(0,0,0,0);color:var(--button-bg);cursor:pointer;font-weight:600}.editor__test-btn i{margin-right:8px}.editor__test-btn:hover{background-color:rgba(var(--button-bg-rgb), 0.08)}.editor__test-btn:disabled{border:1px solid rgba(var(--center-channel-color-rgb), 0.32);color:rgba(var(--center-channel-color-rgb), 0.56);cursor:not-allowed;opacity:.4}.editor__add-row-button{display:flex;align-items:center;padding:10px 16px;border:1px solid var(--button-bg);border-radius:4px;background-color:rgba(0,0,0,0);color:var(--button-bg);cursor:pointer;font-weight:600}.editor__add-row-button i{margin-right:8px;font-size:14px}.editor__add-row-button:hover{background-color:rgba(var(--button-bg-rgb), 0.08)}.editor__add-row-button:disabled{border:1px solid rgba(var(--center-channel-color-rgb), 0.32);color:rgba(var(--center-channel-color-rgb), 0.56);cursor:not-allowed;opacity:.4}.editor__help-text{color:var(--center-channel-color-72);font-size:12px}.editor__help-text p{margin-bottom:0}.editor__help-text a{display:inline-block;margin-top:8px;color:var(--link-color)}.editor__help-text a:hover{text-decoration:underline}
.cel-help-modal__content-container{display:flex;flex-direction:column}.cel-help-modal__content-container .cel-help-modal__content{padding:32px;padding-top:0}.cel-help-modal__content-container .cel-help-additional-info-modal__content{display:flex;flex-direction:column;padding:20px;background-color:rgba(var(--button-bg-rgb), 0.08)}.cel-help-modal__content-container .cel-help-additional-info-modal__content .cel-help-additional-info-modal__header{display:flex;align-items:center;margin-bottom:16px}.cel-help-modal__content-container .cel-help-additional-info-modal__content .cel-help-additional-info-modal__header i{margin-right:8px;color:var(--button-bg);font-size:24px}.cel-help-modal__content-container .cel-help-additional-info-modal__content .cel-help-additional-info-modal__header .cel-help-additional-info-modal__title{font-size:16px;font-weight:600}
.TestResultsModal{margin-top:5vh !important}.TestResultsModal .no-users-found{padding:32px 0;text-align:center}.TestResultsModal .GenericModal__body{padding:0 !important}.TestResultsModal .GenericModal__body .filter-row{padding:0 16px;margin:5px 0 10px}.TestResultsModal .GenericModal__body .filtered-user-list .filter-row span.member-count{margin-top:5px;opacity:.8}
.table-editor{margin-bottom:24px}.table-editor__table{width:100%;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;border-collapse:collapse}.table-editor th{padding:8px 12px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.16);background:rgba(var(--center-channel-color-rgb), 0.04);color:var(--center-channel-color-72);font-size:12px;font-weight:600;text-align:left}.table-editor td{border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08);vertical-align:middle}.table-editor .table-editor__column-header-value{padding-inline:10px}.table-editor th:nth-child(2),.table-editor td:nth-child(2){width:20%}.table-editor th:nth-child(3),.table-editor td:nth-child(3){width:50%}.table-editor th:nth-child(4),.table-editor td:nth-child(4){width:30px;text-align:right}.table-editor__blank-state{padding:16px;text-align:center}.table-editor__blank-state span{color:rgba(var(--center-channel-color-rgb), 0.64)}.table-editor__row-remove{border:none;background:none;color:rgba(var(--center-channel-color-rgb), 0.56);cursor:pointer}.table-editor__row-remove:hover{color:var(--error-text)}.table-editor__actions-row{display:flex;justify-content:space-between;margin-top:12px}.table-editor__add-button-container{padding:8px}
.system-policy-indicator__title{margin-bottom:8px;font-weight:600;line-height:1.5}.system-policy-indicator__description{line-height:1.5}.system-policy-indicator__description strong{font-weight:600}.system-policy-indicator__more-link{padding:0;border:none;background:none;color:var(--link-color);cursor:pointer;font-family:inherit;font-size:inherit;font-weight:600;line-height:inherit;text-decoration:none}.system-policy-indicator__more-link:hover,.system-policy-indicator__more-link:focus{outline:none;text-decoration:underline}.system-policy-indicator__more-link:focus-visible{border-radius:2px;outline:2px solid var(--link-color);outline-offset:2px}.system-policy-indicator__policy-link{color:var(--link-color);font-weight:600;text-decoration:none}.system-policy-indicator__policy-link:hover{text-decoration:underline}.system-policy-indicator__policy-link:visited{color:var(--link-color)}.system-policy-indicator__policy-name{font-weight:600}.system-policy-indicator.compact .system-policy-indicator__main-message{margin-bottom:0}.system-policy-indicator.compact .system-policy-indicator__policy-list{display:none}
.ChannelAccessRulesConfirmModal .modal-body{padding:0}.ChannelAccessRulesConfirmModal .filter-controls{border:none !important}.ChannelAccessRulesConfirmModal .more-modal__details{display:flex}.ChannelAccessRulesConfirmModal .more-modal__details .more-modal__description{display:flex;align-items:center}.ChannelAccessRulesConfirmModal .GenericModal__header__text_container{display:flex;gap:12px}.ChannelAccessRulesConfirmModal .GenericModal__header__text_container .GenericModal__header{display:flex;align-items:center}.ChannelAccessRulesConfirmModal .GenericModal__header__text_container .modal-subheading-container{padding-left:12px;border-left:1px solid rgba(var(--center-channel-color-rgb), 0.16)}.ChannelAccessRulesConfirmModal__summary{padding:0px 32px}.ChannelAccessRulesConfirmModal__message{margin-bottom:16px;color:var(--center-channel-color);font-size:14px;line-height:20px}.ChannelAccessRulesConfirmModal__message strong{font-weight:600}.ChannelAccessRulesConfirmModal__question{margin-bottom:24px;color:var(--center-channel-color);font-size:14px;line-height:20px}.ChannelAccessRulesConfirmModal__details{display:flex;height:500px;flex-direction:column}.ChannelAccessRulesConfirmModal__details .ChannelAccessRulesConfirmModal__buttons{margin:0 32px}.ChannelAccessRulesConfirmModal__details .ChannelAccessRulesConfirmModal__message{padding:0 32px}.ChannelAccessRulesConfirmModal__tabs{display:flex;padding:0 32px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.16)}.ChannelAccessRulesConfirmModal__tab{position:relative;padding:16px 0;border:none;margin-right:32px;background:none;color:rgba(var(--center-channel-color-rgb), 0.64);cursor:pointer;font-size:14px;font-weight:600;transition:color .15s ease}.ChannelAccessRulesConfirmModal__tab:hover{color:var(--center-channel-color)}.ChannelAccessRulesConfirmModal__tab.active{color:var(--button-bg)}.ChannelAccessRulesConfirmModal__tab.active::after{position:absolute;right:0;bottom:-1px;left:0;height:2px;background-color:var(--button-bg);content:""}.ChannelAccessRulesConfirmModal__tab:focus{outline:none}.ChannelAccessRulesConfirmModal__search{padding:16px 32px 0}.ChannelAccessRulesConfirmModal__search .form-control{width:100%}.ChannelAccessRulesConfirmModal__userList{flex:1;padding:16px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08);overflow-y:auto}.ChannelAccessRulesConfirmModal__userList .member-count{padding:8px 0}.ChannelAccessRulesConfirmModal__users{display:flex;flex-direction:column;gap:8px}.ChannelAccessRulesConfirmModal__user{display:flex;align-items:center;padding:12px 16px;border:1px solid rgba(var(--center-channel-color-rgb), 0.08);border-radius:4px;background:var(--center-channel-bg);transition:background-color .15s ease}.ChannelAccessRulesConfirmModal__user:hover{background:rgba(var(--center-channel-color-rgb), 0.04)}.ChannelAccessRulesConfirmModal__userInfo{min-width:0;flex:1}.ChannelAccessRulesConfirmModal__userName{margin-bottom:2px;color:var(--center-channel-color);font-size:14px;font-weight:600}.ChannelAccessRulesConfirmModal__userDetails{display:flex;align-items:center;color:rgba(var(--center-channel-color-rgb), 0.64);font-size:12px;gap:8px}.ChannelAccessRulesConfirmModal__userEmail::before{margin-right:8px;content:"•"}.ChannelAccessRulesConfirmModal__noResults{display:flex;height:200px;align-items:center;justify-content:center;color:rgba(var(--center-channel-color-rgb), 0.64);font-size:14px}.ChannelAccessRulesConfirmModal__buttons{display:flex;align-items:center;justify-content:space-between;padding:24px 0;gap:8px}.ChannelAccessRulesConfirmModal__buttons__left{display:flex;gap:8px}.ChannelAccessRulesConfirmModal__buttons__right{display:flex;gap:8px}@media screen and (max-width: 768px){.ChannelAccessRulesConfirmModal__details{height:400px}.ChannelAccessRulesConfirmModal__tabs{padding:0 16px}.ChannelAccessRulesConfirmModal__details .ChannelAccessRulesConfirmModal__message{padding:16px 16px 0}.ChannelAccessRulesConfirmModal__search{padding:16px 16px 0}.ChannelAccessRulesConfirmModal__userList{padding:16px 16px 0}.ChannelAccessRulesConfirmModal__buttons{flex-direction:column;padding:12px 16px;gap:12px}.ChannelAccessRulesConfirmModal__buttons__left,.ChannelAccessRulesConfirmModal__buttons__right{justify-content:center}.ChannelAccessRulesConfirmModal__buttons .btn{min-width:0;flex:1}}
.channel-activity-warning-content .warning-description{padding-bottom:20px;border-bottom:1px solid var(--center-channel-color-16);margin-bottom:20px;color:var(--center-channel-color);font-family:"Open Sans",sans-serif;font-size:14px;font-weight:400;line-height:20px}.ConfirmModal .activity-warning-checkbox{margin-top:20px}.ConfirmModal .activity-warning-checkbox label{display:flex;align-items:flex-start;padding-left:0;margin-bottom:0;color:var(--center-channel-color);cursor:pointer;font-size:14px;font-weight:600;gap:12px;line-height:20px;user-select:none}.ConfirmModal .activity-warning-checkbox input[type=checkbox]{position:inherit;display:grid;width:1.6rem;height:1.6rem;flex-shrink:0;border:1px solid rgba(var(--center-channel-color-rgb), 0.24);border-radius:3px;margin:0;margin-top:4px;-webkit-appearance:none;appearance:none;background-color:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.24);cursor:pointer;font:inherit;place-content:center;-webkit-transition:background-color 200ms ease-out;-moz-transition:background-color 200ms ease-out;-o-transition:background-color 200ms ease-out;transition:background-color 200ms ease-out}.ConfirmModal .activity-warning-checkbox input[type=checkbox]::before{width:10px;height:10px;background:var(--button-color);clip-path:polygon(0% 57%, 32% 88%, 100% 20%, 88% 8%, 32% 64%, 12% 45%);content:"";transform:scale(0);transform-origin:center center;transition:200ms transform ease-in-out}.ConfirmModal .activity-warning-checkbox input[type=checkbox]:checked::before{transform:scale(1)}.ConfirmModal .activity-warning-checkbox input[type=checkbox]:checked{border-color:var(--button-bg);background:var(--button-bg)}.ConfirmModal .activity-warning-checkbox input[type=checkbox]:disabled{cursor:not-allowed;opacity:.5}
.ChannelSettingsModal__accessRulesTab{display:flex;max-height:100%;flex:1;flex-direction:column;padding-bottom:60px;overflow-y:auto}.ChannelSettingsModal__systemPolicies{margin-bottom:20px}.ChannelSettingsModal__accessRulesHeader{display:flex;flex-direction:column;margin-bottom:16px;gap:8px}.ChannelSettingsModal__accessRulesEditor .table-editor__cell button{color:var(--center-channel-color) !important}.ChannelSettingsModal__accessRulesEditor .table-editor__cell button:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08) !important}.ChannelSettingsModal__accessRulesEditor .editor__help-text{width:75%;color:rgba(var(--center-channel-color-rgb), 0.56) !important}.ChannelSettingsModal__accessRulesTitle{margin:0;color:var(--center-channel-color);font-family:Metropolis,sans-serif;font-size:20px;font-weight:600;line-height:28px}.ChannelSettingsModal__accessRulesSubtitle{margin:0;color:rgba(var(--center-channel-color-rgb), 0.72);font-family:"Open Sans",sans-serif;font-size:12px;font-weight:400;line-height:20px}.ChannelSettingsModal__divider{border:none;border-top:1px solid rgba(var(--center-channel-color-rgb), 0.16);margin:24px 0}.ChannelSettingsModal__autoSyncCheckboxContainer{display:flex;align-items:center;margin-bottom:8px;gap:8px}.ChannelSettingsModal__autoSyncLabel{display:flex;align-items:center;margin:0;cursor:pointer;user-select:none}.ChannelSettingsModal__autoSyncCheckbox{display:grid;width:1.6rem;height:1.6rem;flex-shrink:0;border:1px solid rgba(var(--center-channel-color-rgb), 0.24);border-radius:3px;margin:0;-webkit-appearance:none;appearance:none;background-color:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.24);cursor:pointer;font:inherit;place-content:center;-webkit-transition:background-color 200ms ease-out;-moz-transition:background-color 200ms ease-out;-o-transition:background-color 200ms ease-out;transition:background-color 200ms ease-out}.ChannelSettingsModal__autoSyncCheckbox::before{width:10px;height:10px;background:var(--button-color);clip-path:polygon(0% 57%, 32% 88%, 100% 20%, 88% 8%, 32% 64%, 12% 45%);content:"";transform:scale(0);transform-origin:center center;transition:200ms transform ease-in-out}.ChannelSettingsModal__autoSyncCheckbox:checked::before{transform:scale(1)}.ChannelSettingsModal__autoSyncCheckbox:checked{border-color:var(--button-bg);background:var(--button-bg)}.ChannelSettingsModal__autoSyncCheckbox:disabled{cursor:not-allowed;opacity:.5}.ChannelSettingsModal__autoSyncText{color:var(--center-channel-color);font-family:"Open Sans",sans-serif;font-size:14px;font-weight:400;line-height:20px}.ChannelSettingsModal__autoSyncText.disabled{color:rgba(var(--center-channel-color-rgb), 0.5);cursor:not-allowed}.ChannelSettingsModal__autoSyncDescription{margin:0 0 0 24px;color:rgba(var(--center-channel-color-rgb), 0.56);font-family:"Open Sans",sans-serif;font-size:12px;font-weight:400;line-height:16px}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}@keyframes spin{from{transform:scale(1) rotate(0deg)}to{transform:scale(1) rotate(360deg)}}@keyframes highlight{from{background:rgba(255,255,0,.5)}to{background:none}}@keyframes fadeInOpacity{0%{opacity:0}100%{opacity:1}}.ChannelSettingsModal__configurationTab{display:flex;flex-direction:column;gap:16px}.ChannelSettingsModal__configurationTab .channel_banner_header{display:flex}.ChannelSettingsModal__configurationTab .channel_banner_header .channel_banner_header__text{display:flex;flex:1;flex-direction:column;gap:8px}.ChannelSettingsModal__configurationTab .channel_banner_header .channel_banner_header__text span.heading{color:rgb(var(--center-channel-color-rgb));font-size:16px}.ChannelSettingsModal__configurationTab .channel_banner_header .channel_banner_header__text span.subheading{color:rgba(var(--center-channel-color-rgb), 0.64);font-size:12px}.ChannelSettingsModal__configurationTab .channel_banner_section_body{animation-duration:.3s;animation-iteration-count:1;animation-name:fadeInOpacity;animation-timing-function:ease-in;opacity:1;display:flex;width:100%;height:550px;flex-direction:column;gap:16px}.ChannelSettingsModal__configurationTab .AdvancedTextbox{width:390px}.ChannelSettingsModal__configurationTab .AdvancedTextbox #PreviewInputTextButton{position:absolute;z-index:10;top:5px;right:5px}.ChannelSettingsModal__configurationTab .AdvancedTextbox #channel_banner_banner_text_textbox{min-height:40px;max-height:200px}.ChannelSettingsModal__configurationTab .AdvancedTextbox .textbox-preview-area{height:max-content !important;max-height:200px;overflow-y:auto}.ChannelSettingsModal__configurationTab .AdvancedTextbox .textbox-preview-area .markdown__heading{overflow:hidden;margin:2px;font-size:18px;text-overflow:ellipsis}.ChannelSettingsModal__configurationTab .setting_section{display:flex;flex-direction:row;gap:12px}.ChannelSettingsModal__configurationTab .setting_section .color-input.input-group{width:160px}.ChannelSettingsModal__configurationTab .setting_section span.setting_title{flex:1;padding-top:12px;color:rgb(var(--center-channel-color-rgb));font-size:12px;font-weight:600}.ChannelSettingsModal__configurationTab .setting_section .setting_body{flex:4}.ChannelSettingsModal__configurationTab .setting_section .AdvancedTextbox{margin-top:0 !important}
.ChannelSettingsModal{width:920px !important}.ChannelSettingsModal__infoTabTitle{margin-bottom:4px;color:var(--center-channel-color);font-family:Metropolis,sans-serif;font-size:16px;font-weight:600;line-height:20px}.ChannelSettingsModal label.Input_subheading{color:rgba(var(--center-channel-color-rgb), 0.64);font-family:Open Sans,sans-serif;font-size:12px;font-weight:400}.ChannelSettingsModal .GenericModal__wrapper{display:flex;overflow:visible;max-width:1200px;max-height:90vh;flex-direction:column;border:var(--border-default);border-radius:var(--radius-l);box-shadow:var(--elevation-6)}.ChannelSettingsModal .GenericModal__wrapper .modal-body{display:flex;width:auto;min-height:150px;flex-direction:column;margin:0;gap:24px;overflow-y:auto}.ChannelSettingsModal__bodyWrapper{display:flex;width:100%;max-width:920px;flex-direction:column;gap:24px}.ChannelSettingsModal .settings-table{display:flex;flex-direction:row}.ChannelSettingsModal .settings-table .settings-links{min-width:200px}.ChannelSettingsModal .settings-table .settings-content{display:flex;overflow:visible !important;flex:1;flex-direction:column;padding:0 32px}.ChannelSettingsModal .settings-table .settings-content .AdvancedTextbox{position:relative}.ChannelSettingsModal .settings-table .settings-content .channel-settings-name-container,.ChannelSettingsModal .settings-table .settings-content .AdvancedTextbox{margin-top:24px}.ChannelSettingsModal__infoTab{display:flex;flex-direction:column;padding-bottom:60px}.ChannelSettingsModal__infoTab #PreviewInputTextButton{position:absolute;z-index:10;top:5px;right:5px}.ChannelSettingsModal__infoTab .textbox-preview-area,.ChannelSettingsModal__infoTab #channel_settings_purpose_textbox,.ChannelSettingsModal__infoTab #channel_settings_header_textbox{height:80px !important;border:none !important;box-shadow:none !important}.ChannelSettingsModal__infoTab .suggestion-list{z-index:100000}.ChannelSettingsModal__infoTab .textbox-preview-area{box-shadow:none}.ChannelSettingsModal__typeSelector{margin-top:16px}.ChannelSettingsModal__purposeContainer,.ChannelSettingsModal__headerContainer{margin-top:28px}.ChannelSettingsModal__purposeContainer textarea,.ChannelSettingsModal__headerContainer textarea{width:100%;min-height:8em;max-height:60vh;box-sizing:border-box;padding:12px 16px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;background:var(--center-channel-bg);color:var(--center-channel-color);font-size:14px;line-height:20px;resize:none}.ChannelSettingsModal__purposeContainer textarea:hover,.ChannelSettingsModal__headerContainer textarea:hover{border-color:rgba(var(--center-channel-color-rgb), 0.48)}.ChannelSettingsModal__purposeContainer textarea:focus,.ChannelSettingsModal__headerContainer textarea:focus{border-color:var(--button-bg);box-shadow:inset 0 0 0 1px var(--button-bg)}.ChannelSettingsModal__purposeContainer textarea.with-error,.ChannelSettingsModal__headerContainer textarea.with-error{border-color:var(--error-text)}.ChannelSettingsModal__purposeContainer textarea.with-error:focus,.ChannelSettingsModal__headerContainer textarea.with-error:focus{box-shadow:inset 0 0 0 1px var(--error-text)}.ChannelSettingsModal__headerContainer{margin-top:28px}.ChannelSettingsModal__headerContainer--preview-button{display:flex;align-items:center;padding:4px 8px;border:none;background:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.56);cursor:pointer}.ChannelSettingsModal__headerContainer--preview-button:hover{color:rgba(var(--center-channel-color-rgb), 0.72)}.ChannelSettingsModal__headerContainer--preview-button i{font-size:18px}.ChannelSettingsModal__headerContainer .markdown-preview-wrapper{border:1px solid rgba(var(--center-channel-color-rgb), 0.16)}.ChannelSettingsModal__archiveTab{display:flex;flex-direction:column;gap:16px}.ChannelSettingsModal__archiveTab .btn-danger{align-self:flex-start}@media screen and (max-width: 768px){.ChannelSettingsModal{max-width:100%;margin:0}.ChannelSettingsModal .modal-content{display:flex;height:100vh;max-height:unset;flex-direction:column;border-radius:unset}}@media screen and (max-height: 900px)and (min-width: 768px){.ChannelSettingsModal .modal-content{max-height:90vh}}@media screen and (max-height: 600px){.ChannelSettingsModal .modal-content,.ChannelSettingsModal .GenericModal__wrapper{max-height:85vh !important}}.ChannelSettingsModal .SaveChangesPanel{width:70%}@media screen and (max-width: 768px){.ChannelSettingsModal .SaveChangesPanel{width:75%}}.archiveChannelConfirmModal{display:flex;flex-direction:column;justify-content:center}.archiveChannelConfirmModal .GenericModal__header{display:flex;justify-content:center}.archiveChannelConfirmModal .GenericModal__header h1#genericModalLabel{width:auto}.archiveChannelConfirmModal .GenericModal__body .ConfirmModal__body{text-align:center}.archiveChannelConfirmModal .ConfirmModal__footer{display:flex;justify-content:center;gap:8px}

/*# sourceMappingURL=9084.2e322671c1521be11ff0.css.map*/