.channel_banner{display:flex;width:100%;min-height:32px;max-height:32px;justify-content:center;padding-block:6px;padding-inline:24px;white-space:nowrap}.channel_banner .channel_banner_text{display:block;overflow:hidden;max-width:100%;font-size:13px;line-height:20px;text-align:center;text-overflow:ellipsis}.channel_banner .channel_banner_text a{color:var(--channel-banner-text-color);text-decoration:underline}.channel_banner .channel_banner_text .markdown__heading{overflow:hidden;margin:2px;font-size:18px;text-overflow:ellipsis}.channel_banner .channel_banner_text :first-child{overflow:hidden;text-overflow:ellipsis}.channel_banner .channel_banner_text .markdown__table{background:unset}.channelBannerTooltip{top:-2px !important;overflow:auto;min-width:400px;max-width:min(1000px,70vw);max-height:80vh;pointer-events:auto}

/*# sourceMappingURL=9527.c6d187986841a4ca2789.css.map*/