(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[694],{7344:(e,t,r)=>{"use strict";r.d(t,{A:()=>n});const n=new(r(94224).WebSocketClient)},83040:(e,t,r)=>{"use strict";r.d(t,{A:()=>c});var n=r(62688),o=r.n(n),i=(r(17046),r(4290),r(36418)),a=r.n(i),l=r(14778),s=r(44785);function u(e,t,r){return(t=function(e){var t=function(e){if("object"!=typeof e||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var r=t.call(e,"string");if("object"!=typeof r)return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==typeof t?t:t+""}(t))in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}const p=r.n(s)().div.withConfig({displayName:"WrapperDiv"})(["align-items:center;display:flex;flex-direction:column;height:100%;justify-content:center;width:100%;#root > &{grid-area:announcement;display:flex;word-break:normal;flex-direction:row;gap:10px;height:40px;}"]);class c extends a().PureComponent{constructor(){super(...arguments),u(this,"state",{hasError:!1}),u(this,"clearErrorState",(e=>{e.preventDefault(),e.stopPropagation(),this.setState({hasError:!1})}))}static getDerivedStateFromError(){return{hasError:!0}}render(){return this.state.hasError?a().createElement(p,null,a().createElement(l.FormattedMessage,{id:"pluggable.errorOccurred",defaultMessage:"An error occurred in the {pluginId} plugin.",values:{pluginId:this.props.pluginId}}),a().createElement("br",null),a().createElement("a",{href:"#",onClick:this.clearErrorState},a().createElement(l.FormattedMessage,{id:"pluggable.errorRefresh",defaultMessage:"Refresh?",values:{pluginId:this.props.pluginId}}))):this.props.children}}u(c,"propTypes",{children:o().node.isRequired,pluginId:o().string})},694:(e,t,r)=>{"use strict";r.r(t),r.d(t,{default:()=>m});var n=r(62688),o=r.n(n),i=(r(17046),r(29206),r(36418)),a=r.n(i),l=r(37270),s=r(77440),u=r(7344),p=r(83040);const c=["pluggableId","pluggableName","subComponentName"];function f(e){const{pluggableId:t,pluggableName:r,subComponentName:n=""}=e,o=function(e,t){if(null==e)return{};var r,n,o=function(e,t){if(null==e)return{};var r={};for(var n in e)if({}.hasOwnProperty.call(e,n)){if(-1!==t.indexOf(n))continue;r[n]=e[n]}return r}(e,t);if(Object.getOwnPropertySymbols){var i=Object.getOwnPropertySymbols(e);for(n=0;n<i.length;n++)r=i[n],-1===t.indexOf(r)&&{}.propertyIsEnumerable.call(e,r)&&(o[r]=e[r])}return o}(e,c),i=(0,l.useSelector)(s.O4),f=(0,l.useSelector)((e=>{const t=e.plugins.components;if(Object.hasOwn(t,r))return t[r]}));if(!r||!f)return null;let m,d=[...f];return t&&(d=d.filter((e=>e.id===t))),m="Product"===r?d.map((e=>{if(!n||!e[n])return null;const t=e[n];return a().createElement(p.A,{key:r+e.id,pluginId:e.pluginId},a().createElement(t,Object.assign({},o,{theme:i})))})):d.map((e=>{if(!("component"in e)||!e.component)return null;const t=e.component;return a().createElement(p.A,{key:r+e.id,pluginId:e.pluginId},a().createElement(t,Object.assign({},o,{theme:i,webSocketClient:u.A})))})),a().createElement(a().Fragment,null,m)}f.propTypes={pluggableId:o().string};const m=f},40362:(e,t,r)=>{"use strict";var n=r(56441);function o(){}function i(){}i.resetWarningCache=o,e.exports=function(){function e(e,t,r,o,i,a){if(a!==n){var l=new Error("Calling PropTypes validators directly is not supported by the `prop-types` package. Use PropTypes.checkPropTypes() to call them. Read more at http://fb.me/use-check-prop-types");throw l.name="Invariant Violation",l}}function t(){return e}e.isRequired=e;var r={array:e,bigint:e,bool:e,func:e,number:e,object:e,string:e,symbol:e,any:e,arrayOf:t,element:e,elementType:e,instanceOf:t,node:e,objectOf:t,oneOf:t,oneOfType:t,shape:t,exact:t,checkPropTypes:i,resetWarningCache:o};return r.PropTypes=r,r}},62688:(e,t,r)=>{e.exports=r(40362)()},56441:e=>{"use strict";e.exports="SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED"}}]);
//# sourceMappingURL=694.9004f184abd7b0110a0b.js.map