"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[1380],{81380:(e,t,i)=>{i.r(t),i.d(t,{default:()=>l});var s=i(62688),a=i.n(s),r=i(36418),d=i.n(r),n=i(14778),o=i(46946),m=i(22583),u=i(36397),c=i(90327);function p(e){let{userId:t,timezone:i,onExited:s,postId:a,actions:p}=e;const{formatMessage:l}=(0,n.useIntl)(),_=l({id:"post_reminder_custom_time_picker_modal.defaultMsg",defaultMessage:"Set a reminder"}),f=l({id:"post_reminder.custom_time_picker_modal.header",defaultMessage:"Set a reminder"}),b=l({id:"post_reminder.custom_time_picker_modal.submit_button",defaultMessage:"Set reminder"}),k=(0,c.Yt)(i),h=(0,m.hq)(k),g=(0,r.useCallback)((e=>{p.addPostReminder(t,a,(0,u.Id)(e.toDate())),s()}),[p,a,t,s]);return d().createElement(o.A,{onExited:s,ariaLabel:_,header:f,initialTime:h,onConfirm:g,confirmButtonText:b,relativeDate:!0})}p.propTypes={onExited:a().func.isRequired,postId:a().string.isRequired,actions:a().shape({addPostReminder:a().func.isRequired}).isRequired};const l=p}}]);
//# sourceMappingURL=1380.4ce24587775ec852c812.js.map