"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[4986],{4986:(e,n,a)=>{a.r(n),a.d(n,{default:()=>u});var t=a(62688),s=a.n(t),i=a(71633),r=a.n(i),c=a(36418),o=a.n(c),l=a(87383);function d(e){let{onClick:n,show:a=!1,extraClass:t="",content:s="",name:i}=e;return o().createElement("div",{id:"unreadIndicator"+i,className:r()("nav-pills__unread-indicator",{"nav-pills__unread-indicator--visible":a},t),onClick:n},o().createElement(l.A,{className:"icon icon__unread"}),s)}d.propTypes={onClick:s().func.isRequired,show:s().bool,extraClass:s().string,content:s().node,name:s().string};const u=d}}]);
//# sourceMappingURL=4986.1c2484622a4552777fd0.js.map