.header-footer-route .header-footer-route-container{display:flex;justify-content:space-between}.AccessProblem__body{display:flex;flex-direction:column;align-items:center;justify-content:center}.AccessProblem__title{display:flex;align-items:center;margin:32px 0 16px 0;color:var(--portal-denim);font-family:"Metropolis";font-size:22px;font-style:normal;font-weight:600;line-height:28px;text-align:center}.AccessProblem__description{display:flex;max-width:640px;align-items:center;padding:0 40px;color:var(--portal-denim);font-family:"Open Sans";font-size:14px;font-style:normal;font-weight:400;line-height:20px;text-align:center}

/*# sourceMappingURL=6898.f9c41382e57246523c72.css.map*/