@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.CenterMessageLock{display:flex;align-items:center;padding:16px;border:1px rgba(var(--center-channel-color-rgb), 0.08) solid;border-radius:4px;margin:0 16px 16px;background-color:rgba(var(--center-channel-color-rgb), 0.04);gap:12px}.CenterMessageLock__left{align-self:flex-start;padding:0}.CenterMessageLock__right{margin-top:-2px}.CenterMessageLock__description{color:rgba(var(--center-channel-color-rgb), 0.75)}.CenterMessageLock__icon{color:rgba(var(--center-channel-color-rgb), 0.64)}.CenterMessageLock__title{padding-bottom:4px;font-size:14px;font-weight:600}.CenterMessageLock__cta{padding-top:12px}.CenterMessageLock__cta .btn{display:inline-flex;align-items:center;border:0;border-radius:4px;background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);font-weight:600;transition:all .15s ease-out;font-size:12px}.CenterMessageLock__cta .btn:disabled{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.CenterMessageLock__cta .btn:hover:enabled{background:rgba(var(--button-bg-rgb), 0.12)}.CenterMessageLock__cta .btn:active:enabled{background:rgba(var(--button-bg-rgb), 0.16)}.CenterMessageLock__cta .btn i{display:flex;font-size:18px}.CenterMessageLock__cta .btn i:first-child::before{margin:0 7px 0 0}.CenterMessageLock__cta .btn i:last-child::before{margin:0 0 0 7px}.CenterMessageLock__cta .btn:hover,.CenterMessageLock__cta .btn:focus{color:var(--button-color)}.CenterMessageLock__cta .btn:focus{border:0}.CenterMessageLock__cta .btn.is-admin{position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;border-radius:4px;background:var(--button-bg);color:var(--button-color);font-weight:600;transition:all .15s ease-out}.CenterMessageLock__cta .btn.is-admin:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.CenterMessageLock__cta .btn.is-admin:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.CenterMessageLock__cta .btn.is-admin:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.CenterMessageLock__cta .btn.is-admin:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.CenterMessageLock__cta .btn.is-admin i{display:flex;font-size:18px}.CenterMessageLock__cta .btn.is-admin:hover,.CenterMessageLock__cta .btn.is-admin:focus{color:var(--button-color)}.CenterMessageLock__cta .btn.is-admin:focus{border:0}
.mm-modal-generic-section-item{display:flex;flex-direction:column;gap:8px}.mm-modal-generic-section-item__title{display:flex;align-items:center;padding:0;margin:0 0 8px;color:var(--center-channel-color);font-family:"Open Sans",sans-serif;font-size:14px;font-style:normal;font-weight:600;line-height:20px}.mm-modal-generic-section-item__description{display:flex;align-items:center;padding:0;margin:0;color:rgba(var(--center-channel-color-rgb), 0.64);font-family:"Open Sans",sans-serif;font-size:12px;font-style:normal;font-weight:400;line-height:16px}.mm-modal-generic-section-item__error{display:flex;align-items:center;padding:0;margin:12px 0 0 0;color:var(--error-text);font-family:"Open Sans",sans-serif;font-size:12px;font-style:normal;font-weight:400;line-height:16px}.mm-modal-generic-section-item__error svg{flex-shrink:0;margin-right:6px}.mm-modal-generic-section-item__content{display:flex;flex-direction:column}.mm-modal-generic-section-item__content.inline{flex-direction:row;gap:24px}.mm-modal-generic-section-item__fieldset-checkbox-ctr{display:flex;flex-direction:row;align-items:center;margin-bottom:5px;gap:8px}.mm-modal-generic-section-item__fieldset-checkbox{display:flex;flex-direction:row;align-items:center;margin-bottom:0;cursor:pointer;font-size:14px;gap:8px;line-height:20px}.mm-modal-generic-section-item__fieldset-checkbox span{font-weight:400}.mm-modal-generic-section-item__fieldset-radio{display:flex;flex-direction:column;gap:12px}.mm-modal-generic-section-item__label-radio{display:flex;width:fit-content;flex-direction:row;align-items:center;margin-bottom:0;cursor:pointer;font-size:14px;font-weight:400;gap:8px;line-height:20px}.mm-modal-generic-section-item__fieldset-react-select{max-width:240px;flex-grow:1}.mm-modal-generic-section-item__input-checkbox{width:1.6rem;height:1.6rem}.mm-modal-generic-section-item input[type=checkbox]{display:grid;border:1px solid rgba(var(--center-channel-color-rgb), 0.24);border-radius:3px;margin:0;-webkit-appearance:none;appearance:none;background-color:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.24);cursor:pointer;font:inherit;place-content:center;-webkit-transition:background-color 200ms ease-out;-moz-transition:background-color 200ms ease-out;-o-transition:background-color 200ms ease-out;transition:background-color 200ms ease-out}.mm-modal-generic-section-item input[type=checkbox]::before{width:10px;height:10px;background:var(--button-color);clip-path:polygon(0% 57%, 32% 88%, 100% 20%, 88% 8%, 32% 64%, 12% 45%);content:"";transform:scale(0);transform-origin:center center;transition:200ms transform ease-in-out}.mm-modal-generic-section-item input[type=checkbox]:checked::before{transform:scale(1)}.mm-modal-generic-section-item input[type=checkbox]:checked{border-color:var(--button-bg);background:var(--button-bg)}.mm-modal-generic-section-item input[type=radio]{display:grid;width:1.6rem;height:1.6rem;border:1px solid rgba(var(--center-channel-color-rgb), 0.24);border-radius:50%;margin:0;-webkit-appearance:none;appearance:none;background-color:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.24);cursor:pointer;font:inherit;place-content:center}.mm-modal-generic-section-item input[type=radio]::before{width:8px;height:8px;border-radius:50%;background:var(--button-bg);content:"";transform:scale(0);transform-origin:center center;transition:200ms transform ease-in-out}.mm-modal-generic-section-item input[type=radio]:checked::before{transform:scale(1)}.mm-modal-generic-section-item input[type=radio]:checked{border-color:var(--button-bg)}
.mm-modal-header{display:flex;align-items:center;padding:20px 20px 20px 32px;border-bottom:var(--border-light);background:none;gap:8px}.mm-modal-header__title{padding:0;margin:0;color:var(--center-channel-color);font-family:"Metropolis",serif;font-size:22px;font-style:normal;font-weight:600;line-height:28px;white-space:nowrap}.mm-modal-header__vertical-divider{display:inline-block;width:1px;height:24px;margin:0 8px;background:rgba(var(--center-channel-color-rgb), 0.16);vertical-align:middle}.mm-modal-header__subtitle{overflow:hidden;padding:0;margin:0;color:rgba(var(--center-channel-color-rgb), 0.56);font-family:inherit;font-size:12px;font-style:normal;font-weight:400;line-height:20px;text-overflow:ellipsis;vertical-align:middle;white-space:nowrap}.mm-modal-header__ctr{display:flex;flex:1 1 auto;align-items:center;justify-content:flex-end}@media screen and (max-width: 768px){.mm-modal-header{padding:18px 24px}.mm-modal-header__title{font-size:20px}.mm-modal-header__subtitle{display:none}.mm-modal-header__vertical-divider{display:none}}
.mm-modal-generic-section{display:flex;flex-direction:column}.mm-modal-generic-section .modalSectionHeader{display:flex;flex-direction:column;gap:8px;margin-block-end:24px}.mm-modal-generic-section .modalSectionHeader .modalSectionTitle{display:flex;align-items:center;padding:0;margin:0;color:var(--center-channel-color);font-family:"Metropolis",sans-serif;font-size:16px;font-style:normal;font-weight:600;gap:8px;line-height:24px}.mm-modal-generic-section .modalSectionHeader .modalSectionDescription{display:flex;align-items:center;padding:0;margin:0;color:rgba(var(--center-channel-color-rgb), 0.64);font-family:"Open Sans",sans-serif;font-size:12px;font-style:normal;font-weight:400;line-height:16px}.mm-modal-generic-section .modalSectionContent{display:flex;flex-direction:column;gap:24px}
.modal .ChannelNotificationModal{width:100%;max-width:600px;margin-top:5vh !important;overflow-y:hidden}.modal .ChannelNotificationModal .modal-content{flex-direction:column;border:var(--border-default);border-radius:var(--radius-l);box-shadow:var(--elevation-6);overflow-y:hidden}.modal .ChannelNotificationModal .modal-content .GenericModal__wrapper{display:flex;overflow:hidden;max-height:calc(100vh - 160px);flex-direction:column;border:var(--border-default);border-radius:var(--radius-l);box-shadow:var(--elevation-6)}.modal .ChannelNotificationModal .modal-content .GenericModal__wrapper .modal-header{padding:0 !important}.modal .ChannelNotificationModal .modal-content .GenericModal__wrapper .modal-body{display:flex;width:100%;max-width:1024px;min-height:150px;flex-direction:column;gap:24px;overflow-x:hidden;overflow-y:auto}.modal .ChannelNotificationModal .modal-content .GenericModal__wrapper .modal-body main{display:flex;width:100%;max-width:1024px;min-height:150px;flex-direction:column;padding:28px 32px;gap:24px;overflow-x:hidden;overflow-y:auto}.modal .ChannelNotificationModal .modal-content .GenericModal__wrapper .modal-footer{display:flex;width:100%;max-width:1024px;align-items:center;justify-content:flex-end;gap:8px}.modal .ChannelNotificationModal__ctr{display:flex;place-items:center}.modal .ChannelNotificationModal__reset-btn{display:flex;align-items:center;padding:5px 8px;border:none;border-radius:4px;background:rgba(0,0,0,0);color:var(--button-bg);font-size:12px;font-weight:600;gap:4px}.modal .ChannelNotificationModal__reset-btn i{font-size:16px}.modal .ChannelNotificationModal__reset-btn:hover,.modal .ChannelNotificationModal__reset-btn:active{background:rgba(var(--button-bg-rgb), 0.08)}.modal .ChannelNotificationModal__server-error{flex-grow:1;color:var(--error-text)}.modal .ChannelNotificationModal__divider{border-bottom:var(--border-light)}@media screen and (max-width: 768px){.modal .ChannelNotificationModal{max-width:100%;margin:0}.modal .ChannelNotificationModal .modal-content{display:flex;max-height:100vh;flex-direction:column;border-radius:unset}}@media screen and (max-height: 900px)and (min-width: 768px){.modal .ChannelNotificationModal .modal-content{max-height:calc(100vh - 160px)}}@media screen and (max-height: 600px)and (min-width: 768px){.modal .ChannelNotificationModal .modal-content,.modal .ChannelNotificationModal .GenericModal__wrapper{max-height:85vh !important}}@media screen and (max-width: 640px){.modal .ChannelNotificationModal .GenericModal__wrapper{max-height:unset !important}}
.LessThanMaxFreeUsers,.MoreThanMaxFreeUsers{display:flex;flex-direction:row}.LessThanMaxFreeUsers .titleAndButton,.MoreThanMaxFreeUsers .titleAndButton{display:flex;flex-direction:column;margin-left:20px}.LessThanMaxFreeUsers .titleAndButton>span,.MoreThanMaxFreeUsers .titleAndButton>span{margin-bottom:15px;font-size:16px;font-weight:600;line-height:24px}.MoreThanMaxFreeUsersWrapper{display:flex;flex-direction:row;gap:8px}
.hint-toast{display:flex;flex-wrap:nowrap;align-items:center;padding:4px 4px 4px 12px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;margin:0;background-color:var(--center-channel-bg);box-shadow:0 6px 14px rgba(0,0,0,.12);color:var(--center-channel-color);font-size:14px;font-weight:bold;gap:16px}.hint-toast .hint-toast__message{line-height:20px;text-align:center}.hint-toast .hint-toast__message .shortcut-key{font-weight:600}.hint-toast .hint-toast__dismiss{padding:4px}.hint-toast .hint-toast__dismiss:hover{background-color:var(--center-channel-bg)}.hint-toast .hint-toast__dismiss:hover svg{fill:rgba(var(--center-channel-color-rgb), 0.75)}.hint-toast .hint-toast__dismiss svg{fill:rgba(var(--center-channel-color-rgb), 0.75);vertical-align:middle}.hint-toast .hint-toast__dismiss .close-btn{cursor:pointer;line-height:normal}.hint-toast__wrapper{position:absolute;z-index:3;display:flex;width:100%;align-items:center;justify-content:center}
.scroll-to-bottom-toast{display:flex;align-items:center;justify-content:space-between;padding:4px;padding-left:12px;border-radius:4px;background-color:var(--button-bg);box-shadow:0 4px 6px 0 rgba(0,0,0,.12);color:var(--button-color-rgb);cursor:pointer;font-size:14px;font-weight:600;gap:8px}.scroll-to-bottom-toast:hover{background-color:rgba(var(--button-bg-rgb), 0.88)}.scroll-to-bottom-toast svg{fill:rgb(var(--button-color-rgb));vertical-align:middle}body.enable-animations .scroll-to-bottom-toast{transition-duration:0s;transition-property:opacity,visibility;transition-timing-function:ease-in-out}.scroll-to-bottom-toast .scroll-to-bottom-toast__message{display:inline-block;line-height:20px;vertical-align:middle}.scroll-to-bottom-toast .scroll-to-bottom-toast__message>svg{margin-right:8px}.scroll-to-bottom-toast .scroll-to-bottom-toast__dismiss{display:inline-block;padding:4px;border-radius:4px}.scroll-to-bottom-toast .scroll-to-bottom-toast__dismiss:hover{background-color:var(--button-bg)}.scroll-to-bottom-toast .scroll-to-bottom-toast__dismiss svg{padding-top:1px;fill:rgba(var(--button-color-rgb), 0.64);vertical-align:middle}.scroll-to-bottom-toast .scroll-to-bottom-toast__dismiss .close-btn{cursor:pointer;line-height:normal}.scroll-to-bottom-toast .scroll-to-bottom-toast__dismiss .close-btn:hover{fill:var(--button-color)}
.search-shortcut{display:inline-block;margin:0 4px}.search-shortcut .shortcut-key{margin-right:4px}.search-shortcut .shortcut-key:last-child{margin-right:0}
.toasts-wrapper{position:absolute;z-index:3;display:flex;width:calc(100% - 32px);align-items:center;justify-content:center;margin:16px 16px 0;gap:7px}
#teamMembersModal .GenericModal__header{display:flex;justify-content:center}
.SaveChangesPanel{position:fixed;z-index:1000;display:flex;width:63%;align-items:center;align-self:center;padding:12px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;animation-duration:300ms;animation-fill-mode:forwards;animation-name:entry-animation;animation-timing-function:ease;background:var(--center-channel-bg);box-shadow:var(--elevation-3);font-family:"Open Sans",sans-serif;transition:all 300ms ease}@keyframes entry-animation{from{bottom:0}to{bottom:20px}}@media screen and (max-width: 768px){.SaveChangesPanel{width:95%}}.SaveChangesPanel.error{border-color:var(--dnd-indicator);background:var(--dnd-indicator)}.SaveChangesPanel.saved{border-color:var(--online-indicator);background:var(--online-indicator)}.SaveChangesPanel__message{display:flex;align-items:center;margin:0;color:var(--center-channel-color);font-family:inherit;font-size:14px;font-style:normal;font-weight:600;line-height:20px}.SaveChangesPanel__message span{margin-left:8px}.SaveChangesPanel__message svg{margin-right:10px;color:rgba(var(--center-channel-color-rgb), 0.56)}.SaveChangesPanel__message.error,.SaveChangesPanel__message.saved{color:var(--button-color)}.SaveChangesPanel__message.error svg,.SaveChangesPanel__message.saved svg{color:var(--button-color)}.SaveChangesPanel__btn-ctr{display:flex;flex:1 1 auto;justify-content:flex-end}.SaveChangesPanel__btn-ctr #panelCloseButton{color:rgba(var(--button-color-rgb), 0.64);font-size:16px}.SaveChangesPanel__cancel-btn.btn.error{background:rgba(var(--button-color-rgb), 0.12);color:var(--button-color)}.SaveChangesPanel__cancel-btn.btn.error:hover{background-color:rgba(var(--button-color-rgb), 0.16)}.SaveChangesPanel__save-btn.btn.error{background-color:var(--button-color);color:var(--dnd-indicator)}.SaveChangesPanel__save-btn.btn.error:hover{background-color:rgba(var(--button-color-rgb), 0.9)}.SaveChangesPanel__save-btn.btn.error:disabled{background:rgba(var(--button-color-rgb), 0.16)}
.select-text-description{margin-top:8px;color:rgba(var(--center-channel-color-rgb), 0.64);font-family:Open Sans;font-size:12px;font-style:normal;font-weight:400;line-height:16px}
.modal-access-tab-content .divider-light{margin:24px 0}.modal-access-tab-content .mm-modal-generic-section-item__content{margin-top:24px}.modal-access-tab-content #allowedDomains{margin-top:16px}.modal-access-tab-content .access-invite-section{gap:0}.modal-access-tab-content .access-invite-section #teamInviteContainer{display:flex;align-items:center}.modal-access-tab-content .access-invite-section #teamInviteContainer .Input_container{margin-right:8px}.modal-access-tab-content .access-invite-section #teamInviteContainer .Input_container #teamInviteId{background-color:unset}.modal-header{background-color:var(--center-channel-bg)}
.picture-setting-item{flex:1;margin-left:40px}.picture-setting-item__remove-button{display:flex;align-items:center;margin-top:18px;color:var(--dnd-indicator);text-align:left}.picture-setting-item__remove-button svg{margin-right:6px}.picture-setting-item .team-picture-section{position:relative;width:fit-content}.picture-setting-item .team-picture-section__team-icon{display:flex;width:120px;height:120px;align-items:center;justify-content:center;border-radius:24px;background-color:var(--sidebar-header-bg);cursor:pointer}.picture-setting-item .team-picture-section__team-name{color:#fff;font-family:Metropolis;font-size:56px;font-style:normal;font-weight:600;line-height:56px;text-align:center}.picture-setting-item .team-picture-section .icon-pencil-outline{position:absolute;right:-6px;bottom:-6px;padding:4px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:20px;background:var(--center-channel-bg, #fff);box-shadow:0 2px 3px 0 var(--elevation-1);cursor:pointer}.picture-setting-item .team-picture-section .team-img-preview{width:120px;height:120px;border-radius:24px;cursor:pointer}
.modal-info-tab-content{display:flex}.modal-info-tab-content .name-description-container{flex:2}.modal-info-tab-content .description-section-input .Input_fieldset{height:100%}.modal-info-tab-content #teamName,.modal-info-tab-content #teamDescription{background-color:unset}.modal-info-tab-content .description-setting-item{margin-top:24px}.modal-header{background-color:var(--center-channel-bg)}
.sidebarHeaderContainer{display:flex;height:55px;flex-direction:row;flex-wrap:nowrap;align-items:center;justify-content:space-between;padding:0 16px;color:var(--sidebar-header-text-color)}.sidebarHeaderContainer button#sidebarTeamMenuButton{overflow:hidden;padding:2px 6px;color:inherit;font-family:Metropolis,sans-serif;font-size:16px;gap:1px}.sidebarHeaderContainer button#sidebarTeamMenuButton:hover{background:rgba(var(--sidebar-header-text-color-rgb), 0.08)}.sidebarHeaderContainer button#sidebarTeamMenuButton:active,.sidebarHeaderContainer button#sidebarTeamMenuButton[aria-expanded=true][aria-haspopup=true]{background:rgba(var(--sidebar-header-text-color-rgb), 0.12)}.sidebarHeaderContainer button#sidebarTeamMenuButton>span{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.sidebarHeaderContainer button#sidebarTeamMenuButton>.icon{display:flex;justify-content:center}#sidebarTeamMenu .learnAboutTeamsMenuItem .leading-element,#sidebarTeamMenu .learnAboutTeamsMenuItem .label-elements>span{color:var(--link-color)}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.url-input-main{display:flex;flex-direction:column}.url-input-main .url-input-container{display:flex;min-height:32px;flex-wrap:wrap;align-items:center;margin-top:4px}.url-input-main .url-input-container .url-input-label{max-width:100%;flex:none;margin-right:4px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;line-height:17px;overflow-wrap:anywhere}.url-input-main .url-input-container .url-input-editable-container{width:auto;margin-right:6px}.url-input-main .url-input-container .url-input-editable-container .url-input-editable-wrapper{padding:0 12px}.url-input-main .url-input-container .url-input-editable-container .url-input-editable-wrapper .url-input-editable-path{height:26px;border:0;border-radius:0;font-size:12px;line-height:16px}.url-input-main .url-input-container .url-input-button{border:none;box-shadow:none;color:var(--link-color);font-size:12px;font-weight:600;line-height:16px;padding:0;border:none;background:var(--center-channel-bg);box-shadow:none}.url-input-main .url-input-container .url-input-button:hover,.url-input-main .url-input-container .url-input-button:active,.url-input-main .url-input-container .url-input-button:focus{text-decoration-line:underline}.url-input-main .url-input-container .url-input-button:disabled{color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed;text-decoration:none}.url-input-main .url-input-container .url-input-button .url-input-button-label{line-height:9px}.url-input-main .url-input-error{display:flex;margin-top:5px;color:var(--error-text);font-size:12px;line-height:16px;text-align:left}.url-input-main .url-input-error i{height:14px;align-self:baseline;margin-right:7px;font-size:14px}.url-input-main .url-input-error i::before{margin:0}
.channel-name-input-field{height:34px !important;border:0 !important;border-radius:0 !important}
.public-private-selector{display:flex;flex-direction:row}.public-private-selector .public-private-selector-button{display:flex;min-width:0;box-sizing:border-box;flex:1;align-items:center;padding:12px 22px 12px 12px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;background:var(--center-channel-bg)}.public-private-selector .public-private-selector-button:not(.a11y--focused){box-shadow:var(--elevation-1)}.public-private-selector .public-private-selector-button:not(:first-child){margin-left:8px}.public-private-selector .public-private-selector-button:not(.a11y--focused):hover{border:1px solid rgba(var(--center-channel-color-rgb), 0.16);box-shadow:var(--elevation-2)}.public-private-selector .public-private-selector-button.selected{border:1px solid rgba(var(--sidebar-text-active-border-rgb), 0.32)}.public-private-selector .public-private-selector-button.selected .public-private-selector-button-icon,.public-private-selector .public-private-selector-button.selected .public-private-selector-button-icon-check{fill:var(--button-bg)}.public-private-selector .public-private-selector-button.selected:not(.a11y--focused):hover{border:1px solid rgba(var(--sidebar-text-active-border-rgb), 0.4);box-shadow:var(--elevation-2)}.public-private-selector .public-private-selector-button.disabled,.public-private-selector .public-private-selector-button.locked{border:1px solid rgba(var(--center-channel-color-rgb), 0.16);cursor:not-allowed;opacity:.4}.public-private-selector .public-private-selector-button.disabled:hover,.public-private-selector .public-private-selector-button.locked:hover{border:1px solid rgba(var(--center-channel-color-rgb), 0.16);box-shadow:var(--elevation-1)}.public-private-selector .public-private-selector-button.disabled.selected,.public-private-selector .public-private-selector-button.locked.selected{border:1px solid rgba(var(--sidebar-text-active-border-rgb), 0.32)}.public-private-selector .public-private-selector-button .public-private-selector-button-text{min-width:0;flex:1;margin-left:12px;text-align:left}.public-private-selector .public-private-selector-button .public-private-selector-button-text .public-private-selector-button-title{overflow:hidden;color:var(--center-channel-color);font-size:14px;font-weight:600;line-height:20px;text-overflow:ellipsis;white-space:nowrap}.public-private-selector .public-private-selector-button .public-private-selector-button-text .public-private-selector-button-title .public-private-selector-button-icon-upgrade{display:inline-flex;width:16px;height:16px;margin-left:8px;fill:var(--online-indicator);vertical-align:sub}.public-private-selector .public-private-selector-button .public-private-selector-button-text .public-private-selector-button-description{overflow:hidden;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;line-height:16px;text-overflow:ellipsis;white-space:nowrap}.public-private-selector .public-private-selector-button .public-private-selector-button-icon{display:flex;flex:none;fill:rgba(var(--center-channel-color-rgb), 0.75)}.public-private-selector .public-private-selector-button .public-private-selector-button-icon-check{display:flex;flex:none;margin-left:auto}@media screen and (max-width: 580px){.public-private-selector{flex-direction:column}.public-private-selector .public-private-selector-button:not(:first-child){margin:8px 0 0}}
.new-channel-modal .new-channel-modal-type-selector{margin-top:24px}.new-channel-modal .new-channel-modal-purpose-container{margin-top:28px}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea{width:100%;box-sizing:border-box;background:var(--center-channel-bg);color:var(--center-channel-color);font-size:14px;line-height:20px;resize:none}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea .Input_wrapper textarea.form-control{height:auto;border:none}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea:hover{border-color:rgba(var(--center-channel-color-rgb), 0.48)}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea:focus{border-color:var(--button-bg);box-shadow:inset 0 0 0 1px var(--button-bg)}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea.with-error{border-color:var(--error-text)}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea.with-error:focus{box-shadow:inset 0 0 0 1px var(--error-text)}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-info{margin-top:5px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;line-height:16px;text-align:left}@media screen and (max-width: 640px){.new-channel-modal .modal-content .GenericModal__wrapper{display:flex;height:100vh;flex-direction:column}.new-channel-modal .modal-content .GenericModal__wrapper>.modal-body{flex:1}}#new-channel-with-board-tooltip span{display:block;width:100%;text-align:left !important}#new-channel-with-board-tooltip .title{font-weight:800}#new-channel-with-board-tooltip .description{font-weight:500}@media screen and (max-width: 640px){.app__body.announcement-bar--fixed .new-channel-modal .modal-content .GenericModal__wrapper{height:calc(100vh - 40px)}}
#browseChannelsModal .modal-dialog{margin-top:calc(45vh - 240px) !important}@media screen and (max-width: 640px){#browseChannelsModal .modal-dialog{margin-top:0 !important}}#browseChannelsModal .filter-row{position:relative;padding:0 32px}#browseChannelsModal .filter-row .input-clear{top:16px;right:14px}#browseChannelsModal .filter-row #searchIcon{position:absolute;z-index:2;top:16px;left:42px;color:rgba(var(--center-channel-color-rgb), 0.64);pointer-events:none}#browseChannelsModal .filter-row #searchChannelsTextbox{height:48px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);box-shadow:none;font-size:16px;padding-inline:40px}#browseChannelsModal .filter-row #searchChannelsTextbox::placeholder{color:var(--center-channel-color)}#browseChannelsModal .filter-row #searchChannelsTextbox:focus{border:2px solid var(--button-bg)}#browseChannelsModal .more-modal__dropdown{display:flex;align-items:center;justify-content:space-between;padding:8px 32px;border-bottom:solid 1px rgba(var(--center-channel-color-rgb), 0.16);margin:0}#browseChannelsModal .more-modal__dropdown span{color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;line-height:16px}#browseChannelsModal .more-modal__dropdown #channelCountLabel{color:var(--center-channel-color);font-size:12px;font-weight:400}#browseChannelsModal .more-modal__dropdown #modalPreferenceContainer{display:flex;align-items:center;justify-content:center}#browseChannelsModal .more-modal__dropdown #modalPreferenceContainer .get-app__checkbox{position:relative;display:flex;width:16px;height:16px;align-items:center;border:1px solid rgba(var(--center-channel-color-rgb), 0.24);border-radius:var(--radius-xs);margin-right:6px;background-color:var(--center-channel-bg)}#browseChannelsModal .more-modal__dropdown #modalPreferenceContainer .get-app__checkbox.checked{border:none}#browseChannelsModal .more-modal__dropdown #modalPreferenceContainer .get-app__checkbox svg{position:absolute;top:0;left:0;width:16px;height:16px;fill:var(--button-bg)}#browseChannelsModal .more-modal__dropdown #modalPreferenceContainer #hideJoinedPreferenceCheckbox{display:flex;align-items:center;cursor:pointer}#browseChannelsModal .more-modal__dropdown #modalPreferenceContainer #menuWrapper{display:flex;align-items:center;justify-content:center;padding:4px 6px 4px 8px;border:none;margin-right:10px;background-color:unset}#browseChannelsModal .more-modal__dropdown #modalPreferenceContainer #menuWrapper[aria-expanded=true]{border-radius:4px;background-color:rgba(var(--button-bg-rgb), 0.12)}#browseChannelsModal .more-modal__dropdown #modalPreferenceContainer #menuWrapper:hover{border-radius:4px;background-color:rgba(var(--center-channel-color-rgb), 0.08)}#browseChannelsModal .modal-body{padding:0}#browseChannelsModal .modal-body .filtered-user-list{height:500px}#browseChannelsModal .modal-body .more-modal__row{padding:0 32px;border-bottom:none}#browseChannelsModal .modal-body .more-modal__row .more-modal__details{padding-left:0;color:rgba(var(--center-channel-color-rgb), 0.75)}#browseChannelsModal .modal-body .more-modal__row .more-modal__details svg{flex-shrink:0}#browseChannelsModal .modal-body .more-modal__row .more-modal__details .more-modal__name{align-items:center;margin-top:0}#browseChannelsModal .modal-body .more-modal__row .more-modal__details .more-modal__name span{color:var(--center-channel-color);font-weight:500}#browseChannelsModal .modal-body .more-modal__row .more-modal__details #channelPurposeContainer{display:flex;align-items:center;justify-content:flex-start}#browseChannelsModal .modal-body .more-modal__row .more-modal__details #channelPurposeContainer .dot{width:3px;height:3px;flex-shrink:0;border-radius:50%;background-color:rgba(var(--center-channel-color-rgb), 0.75)}#browseChannelsModal .modal-body .more-modal__row .more-modal__details #channelPurposeContainer .more-modal__description{margin-left:4px;font-weight:400}#browseChannelsModal .modal-body .more-modal__row .more-modal__details #channelPurposeContainer #membershipIndicatorContainer{display:flex;align-items:center}#browseChannelsModal .modal-body .more-modal__row .more-modal__details #channelPurposeContainer #membershipIndicatorContainer span,#browseChannelsModal .modal-body .more-modal__row .more-modal__details #channelPurposeContainer #membershipIndicatorContainer svg{color:var(--online-indicator)}#browseChannelsModal .modal-body .more-modal__row .more-modal__details #channelPurposeContainer span{margin:0 4px;font-size:12px;font-weight:600;line-height:12px;opacity:1}#browseChannelsModal .modal-body .more-modal__row .more-modal__details .shared-channel-icon{width:18px;height:18px;margin-right:6px;color:rgba(61,60,64,.75);font-size:18px;line-height:18px}#browseChannelsModal .modal-body .more-modal__row .more-modal__actions button{display:none;min-width:54px;height:32px;font-size:12px;font-weight:600}#browseChannelsModal .modal-body .more-modal__row:hover,#browseChannelsModal .modal-body .more-modal__row:focus{background-color:rgba(var(--center-channel-color-rgb), 0.08);cursor:pointer}#browseChannelsModal .modal-body .more-modal__row:hover .more-modal__actions .primaryButton,#browseChannelsModal .modal-body .more-modal__row:hover .more-modal__actions .outlineButton,#browseChannelsModal .modal-body .more-modal__row:focus .more-modal__actions .primaryButton,#browseChannelsModal .modal-body .more-modal__row:focus .more-modal__actions .outlineButton{display:inline-block}#browseChannelsModal .modal-body .form-group{padding:0 32px;margin-bottom:0}#browseChannelsModal .modal-body ::-webkit-scrollbar{width:4px}#browseChannelsModal .modal-body ::-webkit-scrollbar-track{background:none}#browseChannelsModal .modal-header .GenericModal__header{display:flex;width:100%;align-items:center;justify-content:space-between;padding-right:4px}#browseChannelsModal .filter-controls{padding-top:24px}#moreChannelsList .primary-message{margin-top:8px;color:var(--center-channel-color);line-height:28px;word-wrap:break-word}#moreChannelsList .secondary-message{margin-bottom:30px}#moreChannelsList #createNewChannelButton{padding:10px 20px}#browseChannelsDropdown .label-elements{padding:2px 4px;font-size:14px;line-height:20px}
#SidebarContainer .SidebarChannel .SidebarLink .channel-pencil-icon{position:relative;display:flex;width:28px;min-width:0;flex:0 0 28px;align-items:center;justify-content:center;padding:0;margin:0;font-size:14px;line-height:18px}

/*# sourceMappingURL=544.32700b0e612a8af731c6.css.map*/