body.app__body #root .main-wrapper.rhs-popout{display:flex;border:none;border-radius:0;margin:0}body.app__body #root .main-wrapper.rhs-popout .sidebar--right{width:100%;max-width:100%;transform:none}body.app__body #root .main-wrapper.rhs-popout .sidebar--right .sidebar-right__body{height:100%}
.Header{display:flex;height:56px;align-items:center;justify-content:space-between;padding:0 16px;border-radius:12px 12px 0 0;background-color:var(--center-channel-bg)}.Header h1,.Header h2,.Header h3,.Header h4,.Header h5,.Header h6{margin:0;line-height:1}.Header h2{color:rgba(var(--center-channel-color-rgb), 1);font-size:16px;font-weight:600}.Header>div{display:flex}.Header>div p{margin:0 0 0 8px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;font-weight:400;line-height:16px}.Header>.spacer{flex:1}
.ThreadMenu .MenuItem__help-text{margin:0}
.ThreadPane{display:grid;grid-template-areas:"header" "pane";grid-template-rows:56px 1fr}.ThreadPane .Header{display:flex;height:56px;align-items:center;justify-content:space-between;padding:12px 16px;border-bottom:var(--border-default);grid-area:header;--button-separator-height: 24px}.ThreadPane .Header .left{display:flex}.ThreadPane .Header .back{display:none;flex-shrink:0}.ThreadPane .Header .FollowButton,.ThreadPane .Header h3 .Button{height:24px;padding:4px 8px;font-size:12px;line-height:16px}.ThreadPane .Header h3{display:inline-grid;align-items:center;margin:0 10px 0 0;color:rgba(var(--center-channel-color-rgb), 1);grid-template-columns:max-content 1fr}.ThreadPane .Header h3>span{padding-right:8px;padding-left:4px;font-size:16px;font-weight:600;line-height:32px;vertical-align:top}.ThreadPane .Header h3 .Button{color:rgba(var(--center-channel-color-rgb), 0.75);font-weight:400}.ThreadPane .Header .MenuWrapper{margin-left:4px}.ThreadPane .Header .MenuWrapper .dropdown-menu{min-width:250px}.ThreadPane .Header .PopoutButton{margin-left:4px}.ThreadPane .ThreadViewer{overflow:hidden;grid-area:pane}.ThreadPane .ThreadViewer .post-right__scroll{padding-top:0}
body.popout{background-color:var(--center-channel-bg)}body.popout .PopoutButton,body.popout .PopoutMenuItem{display:none}

/*# sourceMappingURL=2018.882de84e586e9bdc2637.css.map*/