"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[9392],{88153:(e,t,a)=>{a.d(t,{A:()=>k});var n=a(62688),l=a.n(n),s=a(71633),c=a.n(s),r=a(36418),m=a.n(r),o=a(14778),i=a(81911);const u=e=>{let{url:t="/",className:a,onClick:n}=e;const{formatMessage:l}=(0,o.useIntl)();return m().createElement("div",{className:c()("signup-header",a)},m().createElement(i.Link,{"data-testid":"back_button",onClick:n,to:t},m().createElement("span",{id:"back_button_icon",className:"fa fa-1x fa-angle-left",title:l({id:"generic_icons.back",defaultMessage:"Back Icon"})}),m().createElement(o.FormattedMessage,{id:"web.header.back",defaultMessage:"Back"})))};u.propTypes={url:l().string,className:l().string,onClick:l().func};const k=u},39392:(e,t,a)=>{a.r(t),a.d(t,{default:()=>f});var n=a(62688),l=a.n(n),s=a(71633),c=a.n(s),r=a(36418),m=a.n(r),o=a(37270),i=a(81911),u=a(26614),k=a(88153),d=a(68716),E=a(78451);const b=e=>{let{alternateLink:t,backButtonURL:a,onBackButtonClick:n}=e;const{SiteName:l}=(0,o.useSelector)(u.zj),s=(0,o.useSelector)(u.Ay),r=l||"Mattermost";let b=null;"false"===s.IsLicensed?b=m().createElement(m().Fragment,null,m().createElement(d.A,null),m().createElement("span",{className:"freeBadge"},"TEAM EDITION")):s.SkuShortName===E.gS.Entry&&(b=m().createElement(m().Fragment,null,m().createElement(d.A,null),m().createElement("span",{className:"freeBadge"},"ENTRY EDITION")));let f=l;return"Mattermost"===f&&(f=b?"":m().createElement(d.A,null)),m().createElement("div",{className:c()("hfroute-header",{"has-free-banner":b,"has-custom-site-name":f})},m().createElement("div",{className:"header-main"},m().createElement("div",null,b&&m().createElement(i.Link,{className:"header-logo-link",to:"/","aria-label":r},b),f&&m().createElement(i.Link,{className:"header-logo-link",to:"/","aria-label":r},f)),t),n&&m().createElement(k.A,{className:"header-back-button",url:a,onClick:n}))};b.propTypes={alternateLink:l().element,backButtonURL:l().string,onBackButtonClick:l().func};const f=b}}]);
//# sourceMappingURL=9392.97d5bc5600f317c58ce0.js.map