"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[4526],{34526:(e,a,n)=>{n.r(a),n.d(a,{default:()=>b});var t=n(62688),s=n.n(t),l=n(36418),r=n.n(l),d=n(14778),i=n(37270),u=n(30413),c=n(9916),m=n(70669),o=n(19174),p=n(51877),h=n(77813),C=n(66039),g=n(69440);function b(e){let{setChannelRef:a}=e;const n=(0,d.useIntl)(),t=(0,i.useSelector)(c.OM),s=(0,i.useDispatch)(),b=(0,l.useCallback)((()=>{t.length&&s((0,u.Zi)(t.map((e=>e.id))))}),[t,s]);return 0===t.length?null:r().createElement("div",{className:"SidebarChannelGroup dropDisabled a11y__section"},r().createElement(C.U,{displayName:n.formatMessage({id:"sidebar.types.unreadChannels.displayName",defaultMessage:"UNREADS"})},r().createElement(h.A,{id:"unreads",name:n.formatMessage({id:"sidebar.types.unreadChannels.ariaLabel",defaultMessage:"Unread"})},r().createElement(p.A,{id:"unreads",handleViewCategory:b,numChannels:t.length}),r().createElement(m.wv,null),r().createElement(o.A,{id:"unreads"}))),r().createElement("div",{className:"SidebarChannelGroup_content"},r().createElement("ul",{role:"list",className:"NavGroupContent"},t.map(((e,n)=>r().createElement(g.A,{key:e.id,channelIndex:n,channelId:e.id,setChannelRef:a,isCategoryCollapsed:!1,isCategoryDragged:!1,isDraggable:!1,isAutoSortedCategory:!0}))))))}b.propTypes={setChannelRef:s().func.isRequired}}}]);
//# sourceMappingURL=4526.68bf659b05682f608bb9.js.map