"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[729],{60729:(e,o,n)=>{n.r(o),n.d(o,{default:()=>p});var t=n(37270),s=n(32446),a=n(79751),l=n(62688),i=n.n(l),d=(n(29206),n(36418)),c=n.n(d);const r=e=>{let{modals:o,actions:n}=e;if(!o)return null;const{modalState:t}=o,s=[];for(const e in t)if(Object.hasOwn(t,e)){const o=t[e];if(o.open){const t=c().createElement(o.dialogType,Object.assign({},o.dialogProps,{onExited:()=>{var t,s;n.closeModal(e),null===(t=o.dialogProps)||void 0===t||null===(s=t.onExited)||void 0===s||s.call(t)},onHide:n.closeModal.bind(void 0,e),key:"".concat(e,"_modal")}));s.push(t)}}return c().createElement(c().Fragment,null,s)};r.propTypes={modals:i().shape({modalState:i().objectOf(i().shape({open:i().bool.isRequired,dialogType:i().elementType.isRequired,dialogProps:i().objectOf(i().any)})).isRequired}).isRequired,actions:i().shape({closeModal:i().func.isRequired}).isRequired};const u=r,p=(0,t.connect)((function(e){return{modals:e.views.modals}}),(function(e){return{actions:(0,s.zH)({closeModal:a.O},e)}}))(u)}}]);
//# sourceMappingURL=729.85f4c18c144542516c2d.js.map