.mm-modal-generic-section-item{display:flex;flex-direction:column;gap:8px}.mm-modal-generic-section-item__title{display:flex;align-items:center;padding:0;margin:0 0 8px;color:var(--center-channel-color);font-family:"Open Sans",sans-serif;font-size:14px;font-style:normal;font-weight:600;line-height:20px}.mm-modal-generic-section-item__description{display:flex;align-items:center;padding:0;margin:0;color:rgba(var(--center-channel-color-rgb), 0.64);font-family:"Open Sans",sans-serif;font-size:12px;font-style:normal;font-weight:400;line-height:16px}.mm-modal-generic-section-item__error{display:flex;align-items:center;padding:0;margin:12px 0 0 0;color:var(--error-text);font-family:"Open Sans",sans-serif;font-size:12px;font-style:normal;font-weight:400;line-height:16px}.mm-modal-generic-section-item__error svg{flex-shrink:0;margin-right:6px}.mm-modal-generic-section-item__content{display:flex;flex-direction:column}.mm-modal-generic-section-item__content.inline{flex-direction:row;gap:24px}.mm-modal-generic-section-item__fieldset-checkbox-ctr{display:flex;flex-direction:row;align-items:center;margin-bottom:5px;gap:8px}.mm-modal-generic-section-item__fieldset-checkbox{display:flex;flex-direction:row;align-items:center;margin-bottom:0;cursor:pointer;font-size:14px;gap:8px;line-height:20px}.mm-modal-generic-section-item__fieldset-checkbox span{font-weight:400}.mm-modal-generic-section-item__fieldset-radio{display:flex;flex-direction:column;gap:12px}.mm-modal-generic-section-item__label-radio{display:flex;width:fit-content;flex-direction:row;align-items:center;margin-bottom:0;cursor:pointer;font-size:14px;font-weight:400;gap:8px;line-height:20px}.mm-modal-generic-section-item__fieldset-react-select{max-width:240px;flex-grow:1}.mm-modal-generic-section-item__input-checkbox{width:1.6rem;height:1.6rem}.mm-modal-generic-section-item input[type=checkbox]{display:grid;border:1px solid rgba(var(--center-channel-color-rgb), 0.24);border-radius:3px;margin:0;-webkit-appearance:none;appearance:none;background-color:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.24);cursor:pointer;font:inherit;place-content:center;-webkit-transition:background-color 200ms ease-out;-moz-transition:background-color 200ms ease-out;-o-transition:background-color 200ms ease-out;transition:background-color 200ms ease-out}.mm-modal-generic-section-item input[type=checkbox]::before{width:10px;height:10px;background:var(--button-color);clip-path:polygon(0% 57%, 32% 88%, 100% 20%, 88% 8%, 32% 64%, 12% 45%);content:"";transform:scale(0);transform-origin:center center;transition:200ms transform ease-in-out}.mm-modal-generic-section-item input[type=checkbox]:checked::before{transform:scale(1)}.mm-modal-generic-section-item input[type=checkbox]:checked{border-color:var(--button-bg);background:var(--button-bg)}.mm-modal-generic-section-item input[type=radio]{display:grid;width:1.6rem;height:1.6rem;border:1px solid rgba(var(--center-channel-color-rgb), 0.24);border-radius:50%;margin:0;-webkit-appearance:none;appearance:none;background-color:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.24);cursor:pointer;font:inherit;place-content:center}.mm-modal-generic-section-item input[type=radio]::before{width:8px;height:8px;border-radius:50%;background:var(--button-bg);content:"";transform:scale(0);transform-origin:center center;transition:200ms transform ease-in-out}.mm-modal-generic-section-item input[type=radio]:checked::before{transform:scale(1)}.mm-modal-generic-section-item input[type=radio]:checked{border-color:var(--button-bg)}
.mm-modal-header{display:flex;align-items:center;padding:20px 20px 20px 32px;border-bottom:var(--border-light);background:none;gap:8px}.mm-modal-header__title{padding:0;margin:0;color:var(--center-channel-color);font-family:"Metropolis",serif;font-size:22px;font-style:normal;font-weight:600;line-height:28px;white-space:nowrap}.mm-modal-header__vertical-divider{display:inline-block;width:1px;height:24px;margin:0 8px;background:rgba(var(--center-channel-color-rgb), 0.16);vertical-align:middle}.mm-modal-header__subtitle{overflow:hidden;padding:0;margin:0;color:rgba(var(--center-channel-color-rgb), 0.56);font-family:inherit;font-size:12px;font-style:normal;font-weight:400;line-height:20px;text-overflow:ellipsis;vertical-align:middle;white-space:nowrap}.mm-modal-header__ctr{display:flex;flex:1 1 auto;align-items:center;justify-content:flex-end}@media screen and (max-width: 768px){.mm-modal-header{padding:18px 24px}.mm-modal-header__title{font-size:20px}.mm-modal-header__subtitle{display:none}.mm-modal-header__vertical-divider{display:none}}
.mm-modal-generic-section{display:flex;flex-direction:column}.mm-modal-generic-section .modalSectionHeader{display:flex;flex-direction:column;gap:8px;margin-block-end:24px}.mm-modal-generic-section .modalSectionHeader .modalSectionTitle{display:flex;align-items:center;padding:0;margin:0;color:var(--center-channel-color);font-family:"Metropolis",sans-serif;font-size:16px;font-style:normal;font-weight:600;gap:8px;line-height:24px}.mm-modal-generic-section .modalSectionHeader .modalSectionDescription{display:flex;align-items:center;padding:0;margin:0;color:rgba(var(--center-channel-color-rgb), 0.64);font-family:"Open Sans",sans-serif;font-size:12px;font-style:normal;font-weight:400;line-height:16px}.mm-modal-generic-section .modalSectionContent{display:flex;flex-direction:column;gap:24px}
.modal .ChannelNotificationModal{width:100%;max-width:600px;margin-top:5vh !important;overflow-y:hidden}.modal .ChannelNotificationModal .modal-content{flex-direction:column;border:var(--border-default);border-radius:var(--radius-l);box-shadow:var(--elevation-6);overflow-y:hidden}.modal .ChannelNotificationModal .modal-content .GenericModal__wrapper{display:flex;overflow:hidden;max-height:calc(100vh - 160px);flex-direction:column;border:var(--border-default);border-radius:var(--radius-l);box-shadow:var(--elevation-6)}.modal .ChannelNotificationModal .modal-content .GenericModal__wrapper .modal-header{padding:0 !important}.modal .ChannelNotificationModal .modal-content .GenericModal__wrapper .modal-body{display:flex;width:100%;max-width:1024px;min-height:150px;flex-direction:column;gap:24px;overflow-x:hidden;overflow-y:auto}.modal .ChannelNotificationModal .modal-content .GenericModal__wrapper .modal-body main{display:flex;width:100%;max-width:1024px;min-height:150px;flex-direction:column;padding:28px 32px;gap:24px;overflow-x:hidden;overflow-y:auto}.modal .ChannelNotificationModal .modal-content .GenericModal__wrapper .modal-footer{display:flex;width:100%;max-width:1024px;align-items:center;justify-content:flex-end;gap:8px}.modal .ChannelNotificationModal__ctr{display:flex;place-items:center}.modal .ChannelNotificationModal__reset-btn{display:flex;align-items:center;padding:5px 8px;border:none;border-radius:4px;background:rgba(0,0,0,0);color:var(--button-bg);font-size:12px;font-weight:600;gap:4px}.modal .ChannelNotificationModal__reset-btn i{font-size:16px}.modal .ChannelNotificationModal__reset-btn:hover,.modal .ChannelNotificationModal__reset-btn:active{background:rgba(var(--button-bg-rgb), 0.08)}.modal .ChannelNotificationModal__server-error{flex-grow:1;color:var(--error-text)}.modal .ChannelNotificationModal__divider{border-bottom:var(--border-light)}@media screen and (max-width: 768px){.modal .ChannelNotificationModal{max-width:100%;margin:0}.modal .ChannelNotificationModal .modal-content{display:flex;max-height:100vh;flex-direction:column;border-radius:unset}}@media screen and (max-height: 900px)and (min-width: 768px){.modal .ChannelNotificationModal .modal-content{max-height:calc(100vh - 160px)}}@media screen and (max-height: 600px)and (min-width: 768px){.modal .ChannelNotificationModal .modal-content,.modal .ChannelNotificationModal .GenericModal__wrapper{max-height:85vh !important}}@media screen and (max-width: 640px){.modal .ChannelNotificationModal .GenericModal__wrapper{max-height:unset !important}}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.url-input-main{display:flex;flex-direction:column}.url-input-main .url-input-container{display:flex;min-height:32px;flex-wrap:wrap;align-items:center;margin-top:4px}.url-input-main .url-input-container .url-input-label{max-width:100%;flex:none;margin-right:4px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;line-height:17px;overflow-wrap:anywhere}.url-input-main .url-input-container .url-input-editable-container{width:auto;margin-right:6px}.url-input-main .url-input-container .url-input-editable-container .url-input-editable-wrapper{padding:0 12px}.url-input-main .url-input-container .url-input-editable-container .url-input-editable-wrapper .url-input-editable-path{height:26px;border:0;border-radius:0;font-size:12px;line-height:16px}.url-input-main .url-input-container .url-input-button{border:none;box-shadow:none;color:var(--link-color);font-size:12px;font-weight:600;line-height:16px;padding:0;border:none;background:var(--center-channel-bg);box-shadow:none}.url-input-main .url-input-container .url-input-button:hover,.url-input-main .url-input-container .url-input-button:active,.url-input-main .url-input-container .url-input-button:focus{text-decoration-line:underline}.url-input-main .url-input-container .url-input-button:disabled{color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed;text-decoration:none}.url-input-main .url-input-container .url-input-button .url-input-button-label{line-height:9px}.url-input-main .url-input-error{display:flex;margin-top:5px;color:var(--error-text);font-size:12px;line-height:16px;text-align:left}.url-input-main .url-input-error i{height:14px;align-self:baseline;margin-right:7px;font-size:14px}.url-input-main .url-input-error i::before{margin:0}
.channel-name-input-field{height:34px !important;border:0 !important;border-radius:0 !important}
.public-private-selector{display:flex;flex-direction:row}.public-private-selector .public-private-selector-button{display:flex;min-width:0;box-sizing:border-box;flex:1;align-items:center;padding:12px 22px 12px 12px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;background:var(--center-channel-bg)}.public-private-selector .public-private-selector-button:not(.a11y--focused){box-shadow:var(--elevation-1)}.public-private-selector .public-private-selector-button:not(:first-child){margin-left:8px}.public-private-selector .public-private-selector-button:not(.a11y--focused):hover{border:1px solid rgba(var(--center-channel-color-rgb), 0.16);box-shadow:var(--elevation-2)}.public-private-selector .public-private-selector-button.selected{border:1px solid rgba(var(--sidebar-text-active-border-rgb), 0.32)}.public-private-selector .public-private-selector-button.selected .public-private-selector-button-icon,.public-private-selector .public-private-selector-button.selected .public-private-selector-button-icon-check{fill:var(--button-bg)}.public-private-selector .public-private-selector-button.selected:not(.a11y--focused):hover{border:1px solid rgba(var(--sidebar-text-active-border-rgb), 0.4);box-shadow:var(--elevation-2)}.public-private-selector .public-private-selector-button.disabled,.public-private-selector .public-private-selector-button.locked{border:1px solid rgba(var(--center-channel-color-rgb), 0.16);cursor:not-allowed;opacity:.4}.public-private-selector .public-private-selector-button.disabled:hover,.public-private-selector .public-private-selector-button.locked:hover{border:1px solid rgba(var(--center-channel-color-rgb), 0.16);box-shadow:var(--elevation-1)}.public-private-selector .public-private-selector-button.disabled.selected,.public-private-selector .public-private-selector-button.locked.selected{border:1px solid rgba(var(--sidebar-text-active-border-rgb), 0.32)}.public-private-selector .public-private-selector-button .public-private-selector-button-text{min-width:0;flex:1;margin-left:12px;text-align:left}.public-private-selector .public-private-selector-button .public-private-selector-button-text .public-private-selector-button-title{overflow:hidden;color:var(--center-channel-color);font-size:14px;font-weight:600;line-height:20px;text-overflow:ellipsis;white-space:nowrap}.public-private-selector .public-private-selector-button .public-private-selector-button-text .public-private-selector-button-title .public-private-selector-button-icon-upgrade{display:inline-flex;width:16px;height:16px;margin-left:8px;fill:var(--online-indicator);vertical-align:sub}.public-private-selector .public-private-selector-button .public-private-selector-button-text .public-private-selector-button-description{overflow:hidden;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;line-height:16px;text-overflow:ellipsis;white-space:nowrap}.public-private-selector .public-private-selector-button .public-private-selector-button-icon{display:flex;flex:none;fill:rgba(var(--center-channel-color-rgb), 0.75)}.public-private-selector .public-private-selector-button .public-private-selector-button-icon-check{display:flex;flex:none;margin-left:auto}@media screen and (max-width: 580px){.public-private-selector{flex-direction:column}.public-private-selector .public-private-selector-button:not(:first-child){margin:8px 0 0}}
.new-channel-modal .new-channel-modal-type-selector{margin-top:24px}.new-channel-modal .new-channel-modal-purpose-container{margin-top:28px}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea{width:100%;box-sizing:border-box;background:var(--center-channel-bg);color:var(--center-channel-color);font-size:14px;line-height:20px;resize:none}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea .Input_wrapper textarea.form-control{height:auto;border:none}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea:hover{border-color:rgba(var(--center-channel-color-rgb), 0.48)}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea:focus{border-color:var(--button-bg);box-shadow:inset 0 0 0 1px var(--button-bg)}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea.with-error{border-color:var(--error-text)}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea.with-error:focus{box-shadow:inset 0 0 0 1px var(--error-text)}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-info{margin-top:5px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;line-height:16px;text-align:left}@media screen and (max-width: 640px){.new-channel-modal .modal-content .GenericModal__wrapper{display:flex;height:100vh;flex-direction:column}.new-channel-modal .modal-content .GenericModal__wrapper>.modal-body{flex:1}}#new-channel-with-board-tooltip span{display:block;width:100%;text-align:left !important}#new-channel-with-board-tooltip .title{font-weight:800}#new-channel-with-board-tooltip .description{font-weight:500}@media screen and (max-width: 640px){.app__body.announcement-bar--fixed .new-channel-modal .modal-content .GenericModal__wrapper{height:calc(100vh - 40px)}}
.channel-members-rhs__members-container{flex:1 1 auto;padding:0 4px 16px}.channel-members-rhs__member-list-separator{padding:0px 12px;margin-top:16px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;font-weight:600;letter-spacing:.02em;line-height:28px;text-transform:uppercase}.channel-members-rhs__member-list-separator--first{margin-top:0px}.channel-members-rhs__alert-container{padding:0 20px 15px}.channel-members-rhs__alert-container.policy-enforced{padding:0}.channel-members-rhs__alert-container.policy-enforced .AlertBanner{padding-bottom:8px;border:none;border-radius:0;border-bottom:1px solid var(--center-channel-color-8, rgba(63, 67, 80, 0.08))}.channel-members-rhs__alert-container.policy-enforced .TagGroup{margin-top:12px}.channel-members-rhs__member{display:flex;flex-direction:row;align-items:center;padding:8px 16px;border-radius:4px}.channel-members-rhs__member:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.75)}.channel-members-rhs__member:hover .channel-members-rhs__send-message{display:block;flex:0 0 auto}.channel-members-rhs__member .ProfileSpan{display:flex;width:100%;flex-direction:row;align-items:center;padding:4px 0}.channel-members-rhs__member .ProfileSpan .profileSpan_userInfo{display:flex;overflow:hidden;flex-grow:1;cursor:pointer;text-overflow:ellipsis;white-space:nowrap}.channel-members-rhs__member .MenuWrapper{font-size:11px;font-weight:600}.channel-members-rhs__avatar{flex-basis:fit-content;flex-shrink:0}.channel-members-rhs__display-name{display:inline;overflow:hidden;margin-left:8px;color:var(--center-channel-color);font-size:14px;gap:8px;line-height:20px;text-overflow:ellipsis}.channel-members-rhs__username{margin-left:4px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;line-height:18px}.channel-members-rhs__send-message{display:none;width:24px;height:24px;padding:0;border:0;border-radius:4px;margin-left:8px;background-color:rgba(0,0,0,0)}.channel-members-rhs__send-message:hover{background-color:rgba(var(--center-channel-color-rgb), 0.12)}.channel-members-rhs__send-message .icon{color:rgba(var(--center-channel-color-rgb), 0.64);font-size:14.4px}.channel-members-rhs__role-chooser{display:none;flex-basis:fit-content;flex-shrink:0}.channel-members-rhs__role-chooser.editing{display:block}.channel-members-rhs__role-chooser .MenuWrapper{padding:6px 10px;border-radius:4px}.channel-members-rhs__role-chooser .MenuWrapper.MenuWrapper--open{background:rgba(var(--button-bg-rgb), 0.16)}.channel-members-rhs__role-chooser .MenuWrapper:not(.MenuWrapper--open):hover{background:rgba(var(--center-channel-color-rgb), 0.08)}.channel-members-rhs__shared-icon{margin:0 0 0 4px;font-size:16px;line-height:20px}
.info-toast{position:fixed;z-index:99;right:16px;bottom:16px;display:grid;width:fit-content;min-height:40px;align-items:center;padding:8px;border-radius:4px;background:rgb(var(--center-channel-color-rgb));box-shadow:0 4px 6px rgba(0,0,0,.12);color:rgb(var(--center-channel-bg-rgb));font-weight:600;grid-template-columns:min-content auto min-content auto;line-height:20px}.info-toast .info-toast__icon_button{border:none;background:none;color:inherit}.info-toast span{padding-left:4px}.info-toast>div{display:flex;align-items:center}.info-toast>div .Icon{font-size:16px}.info-toast__undo{display:flex;height:24px;align-items:center;padding:6px 10px;border:none;border-radius:4px;margin-right:16px;margin-left:8px;background:var(--button-bg);color:var(--sidebar-text);font-size:11px;font-weight:600;line-height:10px}.toast-appear{opacity:0;transform:translateY(150px)}.toast-appear-active{opacity:1;transform:translateY(0);transition:all 500ms ease}
@media(min-width: 758px){#restorePostModal .modal-dialog,#restorePostModal .modal-content{width:832px}#restorePostModal .modal-content{max-width:100%}}
.edit-post-history__container .edit-post-history__icon__button.toggleCollapseButton{border:none;background:none;pointer-events:none}.edit-post-history__container .edit-post-history__icon__button.restore-icon{width:28px;height:28px;border:none;border-radius:4px;background:none}.edit-post-history__container .edit-post-history__icon__button.restore-icon:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.75)}.edit-post-history__container .edit-post-history__icon__button.restore-icon i.icon.icon-restore{width:16px;height:16px}.edit-post-history__container .post-image__columns .post-image__column,.edit-post-history__container .post-image__columns .post-image__thumbnail{cursor:default}
.sidebar-right__edit-post-history .simplebar-content{display:flex;flex-direction:column}.edit-post-history__error_container{display:flex;flex:1;align-items:center;justify-content:center}.edit-post-history__error_item{display:flex;flex-direction:column;align-items:center;justify-content:center;padding:56px;text-align:center}.edit-post-history__error_heading{color:var(--center-channel-color);font-size:20px;font-weight:600;line-height:28px}.edit-post-history__error_subheading{color:rgba(var(--center-channel-color-rgb), 0.75);font-weight:400}
.FileSearchResultItem{display:flex;overflow:hidden;max-width:600px;flex-direction:row;flex-grow:1;align-items:center;padding:11px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;margin:0 14px 8px 14px;background:rgba(0,0,0,0);color:var(--center-channel-color);cursor:pointer;transition:box-shadow .15s ease}.FileSearchResultItem .Menu__content{border:1px solid rgba(var(--center-channel-color-rgb), 0.16);background-color:var(--center-channel-bg)}.FileSearchResultItem:hover,.FileSearchResultItem:focus-within,.FileSearchResultItem.keep-open{overflow:visible;box-shadow:0 2px 3px 0 rgba(0,0,0,.1),0 2px 3px 0 rgba(0,0,0,.1)}.FileSearchResultItem:hover .action-icon,.FileSearchResultItem:focus-within .action-icon,.FileSearchResultItem.keep-open .action-icon{display:flex;opacity:1}.FileSearchResultItem:hover .MenuWrapper,.FileSearchResultItem:focus-within .MenuWrapper,.FileSearchResultItem.keep-open .MenuWrapper{display:block;opacity:1}.FileSearchResultItem:hover .fileData,.FileSearchResultItem:focus-within .fileData,.FileSearchResultItem.keep-open .fileData{overflow:hidden}.FileSearchResultItem .file-icon{width:4rem;min-width:4rem;height:4rem}.FileSearchResultItem .fileData{display:flex;min-width:0;flex-direction:column;flex-grow:1;padding:0 11px;font-size:12px;font-weight:600;text-overflow:ellipsis;white-space:nowrap}.FileSearchResultItem .fileData .fileDataName{overflow:hidden;margin-bottom:3px;text-align:left;text-overflow:ellipsis}.FileSearchResultItem .fileData .fileMetadata{display:flex;flex-direction:row;font-weight:400;gap:8px}.FileSearchResultItem .fileData .fileMetadata>:not(.Tag){opacity:.73}.FileSearchResultItem .fileData .fileMetadata .Tag{max-width:100px}.FileSearchResultItem .post-image{min-width:4rem}.FileSearchResultItem .action-icon{display:none;margin-left:2px}.FileSearchResultItem .action-icon.download-icon{margin-right:2px}.FileSearchResultItem .action-icon svg{display:flex}.FileSearchResultItem .MenuWrapper{display:flex;opacity:0}
.FilesFilterMenu .MenuWrapper{z-index:100;align-self:end}.FilesFilterMenu .MenuWrapper .action-icon{z-index:5;display:flex;min-width:32px;height:32px;align-items:center;justify-content:center;padding:0;border:none;border-radius:4px;background:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.75);cursor:pointer;text-align:center}.FilesFilterMenu .MenuWrapper .action-icon .icon-dot{position:absolute;top:6px;right:6px;width:10px;height:10px;border:2px solid var(--center-channel-bg);border-radius:50%;background-color:var(--button-bg)}.FilesFilterMenu .MenuWrapper .action-icon:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.75)}.FilesFilterMenu .MenuItem span.icon{position:absolute;right:13px;color:var(--button-bg)}
.MessagesOrFilesSelector{display:flex;align-items:center;padding:7px 16px 7px 14px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08)}.MessagesOrFilesSelector .buttons-container{flex-grow:1;margin:7px 0}.MessagesOrFilesSelector .tab{padding:4px 12px;border:0;border-radius:4px;margin-right:4px;background-color:rgba(var(--center-channel-bg-rgb), 1);color:rgba(var(--center-channel-color-rgb), 0.75);cursor:pointer;font-weight:600;text-decoration:none}.MessagesOrFilesSelector .tab.active{border-radius:4px;background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.MessagesOrFilesSelector .tab.active .counter{background-color:rgba(var(--button-bg-rgb), 0.08)}.MessagesOrFilesSelector .tab .counter{position:relative;bottom:1px;padding:1px 6px;border-radius:8px;margin-left:4px;background-color:rgba(var(--center-channel-color-rgb), 0.08);font-size:10px;font-weight:700}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.CenterMessageLock{display:flex;align-items:center;padding:16px;border:1px rgba(var(--center-channel-color-rgb), 0.08) solid;border-radius:4px;margin:0 16px 16px;background-color:rgba(var(--center-channel-color-rgb), 0.04);gap:12px}.CenterMessageLock__left{align-self:flex-start;padding:0}.CenterMessageLock__right{margin-top:-2px}.CenterMessageLock__description{color:rgba(var(--center-channel-color-rgb), 0.75)}.CenterMessageLock__icon{color:rgba(var(--center-channel-color-rgb), 0.64)}.CenterMessageLock__title{padding-bottom:4px;font-size:14px;font-weight:600}.CenterMessageLock__cta{padding-top:12px}.CenterMessageLock__cta .btn{display:inline-flex;align-items:center;border:0;border-radius:4px;background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);font-weight:600;transition:all .15s ease-out;font-size:12px}.CenterMessageLock__cta .btn:disabled{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.CenterMessageLock__cta .btn:hover:enabled{background:rgba(var(--button-bg-rgb), 0.12)}.CenterMessageLock__cta .btn:active:enabled{background:rgba(var(--button-bg-rgb), 0.16)}.CenterMessageLock__cta .btn i{display:flex;font-size:18px}.CenterMessageLock__cta .btn i:first-child::before{margin:0 7px 0 0}.CenterMessageLock__cta .btn i:last-child::before{margin:0 0 0 7px}.CenterMessageLock__cta .btn:hover,.CenterMessageLock__cta .btn:focus{color:var(--button-color)}.CenterMessageLock__cta .btn:focus{border:0}.CenterMessageLock__cta .btn.is-admin{position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;border-radius:4px;background:var(--button-bg);color:var(--button-color);font-weight:600;transition:all .15s ease-out}.CenterMessageLock__cta .btn.is-admin:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.CenterMessageLock__cta .btn.is-admin:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.CenterMessageLock__cta .btn.is-admin:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.CenterMessageLock__cta .btn.is-admin:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.CenterMessageLock__cta .btn.is-admin i{display:flex;font-size:18px}.CenterMessageLock__cta .btn.is-admin:hover,.CenterMessageLock__cta .btn.is-admin:focus{color:var(--button-color)}.CenterMessageLock__cta .btn.is-admin:focus{border:0}
.SearchLimitsBanner__wrapper{padding-top:16px}
.SearchResults .messages-or-files .active{background-color:rgba(var(--buton-bg-rgb), 0.08)}.SearchResults .messages-or-files a{padding:4px 12px;margin-left:10px;text-decoration:none}.SearchResults .channel-files__header{display:flex;align-items:center;justify-content:space-between;padding:7px 14px}.SearchResults .channel-files__header .channel-files__title{font-size:14px;font-weight:600}.SearchResults .channel-files-container{padding-top:0}

/*# sourceMappingURL=1781.7755fcf8858efde6fa70.css.map*/