"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[5808],{25808:(e,a,n)=>{n.r(a),n.d(a,{default:()=>d});var l=n(37270),t=n(14776),o=n(7430),r=n(79751),m=n(36418),s=n.n(m),i=n(67277),u=n(11053),c=n(78451);const p={openModal:r.q},d=(0,l.connect)((function(e){var a;const n=(0,t.H7)(e),l=(0,o.HW)(e);return{username:null==l?void 0:l.username,teamDisplayName:null!==(a=null==n?void 0:n.display_name)&&void 0!==a?a:""}}),p)((function(e){return e.username?s().createElement("div",{className:"mobileSidebarHeader"},s().createElement("h1",null,e.teamDisplayName),s().createElement("div",{className:"mobileSidebarHeader__username"},s().createElement("span",null,"@"+e.username),s().createElement(i.A,{showTooltip:!1,emojiStyle:{verticalAlign:"top"},onClick:function(a){a.stopPropagation();const n={modalId:c.IQ.CUSTOM_STATUS,dialogType:u.A};e.openModal(n)}}))):null}))}}]);
//# sourceMappingURL=5808.4feb1b1e8ed94cea1a1a.js.map